@@ -23,7 +23,6 @@ import com.google.gwt.dev.util.collect.HashSet;
 import com.google.gwt.view.client.Range;
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.apache.commons.lang3.StringUtils;
-import org.dashbuilder.common.client.error.ClientRuntimeError;
 import org.dashbuilder.dataset.DataSet;
 import org.dashbuilder.dataset.DataSetLookup;
 import org.dashbuilder.dataset.DataSetOp;
@@ -31,12 +30,13 @@ import org.dashbuilder.dataset.client.DataSetReadyCallback;
 import org.dashbuilder.dataset.filter.ColumnFilter;
 import org.dashbuilder.dataset.filter.DataSetFilter;
 import org.dashbuilder.dataset.sort.SortOrder;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.jboss.errai.security.shared.api.identity.User;
 import org.jbpm.workbench.common.client.PerspectiveIds;
+import org.jbpm.workbench.common.client.dataset.ErrorHandlerBuilder;
 import org.jbpm.workbench.common.client.filters.active.ActiveFilterItem;
 import org.jbpm.workbench.common.client.filters.basic.BasicFilterAddEvent;
 import org.jbpm.workbench.common.client.filters.basic.BasicFilterRemoveEvent;
-import org.jbpm.workbench.common.client.list.ExtendedPagedTable;
 import org.jbpm.workbench.common.client.list.ListTable;
 import org.jbpm.workbench.common.client.menu.ServerTemplateSelectorMenuBuilder;
 import org.jbpm.workbench.df.client.filter.FilterSettings;
@@ -46,6 +46,7 @@ import org.jbpm.workbench.df.client.list.DataSetQueryHelper;
 import org.jbpm.workbench.pr.client.editors.instance.signal.ProcessInstanceSignalPresenter;
 import org.jbpm.workbench.pr.client.resources.i18n.Constants;
 import org.jbpm.workbench.pr.events.ProcessInstanceSelectionEvent;
+import org.jbpm.workbench.pr.model.ProcessInstanceKey;
 import org.jbpm.workbench.pr.model.ProcessInstanceSummary;
 import org.jbpm.workbench.pr.service.ProcessService;
 import org.junit.Before;
@@ -74,7 +75,10 @@ import org.uberfire.workbench.model.ActivityResourceType;
 import static java.util.Arrays.asList;
 import static java.util.Collections.singletonMap;
 import static org.dashbuilder.dataset.filter.FilterFactory.equalsTo;
+import static org.dashbuilder.dataset.filter.FilterFactory.greaterThan;
+import static org.dashbuilder.dataset.filter.FilterFactory.in;
 import static org.dashbuilder.dataset.filter.FilterFactory.likeTo;
+import static org.dashbuilder.dataset.filter.FilterFactory.lowerOrEqualsTo;
 import static org.jbpm.workbench.common.client.PerspectiveIds.*;
 import static org.jbpm.workbench.pr.model.ProcessInstanceDataSetConstants.*;
 import static org.junit.Assert.*;
@@ -88,6 +92,7 @@ import static org.mockito.Mockito.*;
 public class ProcessInstanceListPresenterTest {
 
     private static final String PERSPECTIVE_ID = PerspectiveIds.PROCESS_INSTANCES;
+    private String datasetUId = PROCESS_INSTANCE_DATASET;
 
     private org.jbpm.workbench.common.client.resources.i18n.Constants commonConstants;
 
@@ -133,10 +138,10 @@ public class ProcessInstanceListPresenterTest {
     private User identity;
 
     @Mock
-    ServerTemplateSelectorMenuBuilder serverTemplateSelectorMenuBuilder;
+    private ServerTemplateSelectorMenuBuilder serverTemplateSelectorMenuBuilder;
 
     @Mock
-    UberfireBreadcrumbs breadcrumbs;
+    private UberfireBreadcrumbs breadcrumbs;
 
     @Mock
     private PerspectiveManager perspectiveManager;
@@ -150,7 +155,13 @@ public class ProcessInstanceListPresenterTest {
     private FilterSettingsManager filterSettingsManager;
 
     @Mock
-    EventSourceMock<ProcessInstanceSelectionEvent> processInstanceSelectionEvent = new EventSourceMock<>();
+    private EventSourceMock<ProcessInstanceSelectionEvent> processInstanceSelectionEvent = new EventSourceMock<>();
+
+    @Mock
+    private ManagedInstance<ErrorHandlerBuilder> errorHandlerBuilder;
+
+    @Spy
+    private ErrorHandlerBuilder errorHandler;
 
     @InjectMocks
     private ProcessInstanceListPresenter presenter;
@@ -162,7 +173,8 @@ public class ProcessInstanceListPresenterTest {
 
     public static ProcessInstanceSummary createProcessInstanceSummary(Long key,
                                                                       Integer status) {
-        return new ProcessInstanceSummary(key,
+        return new ProcessInstanceSummary("serverTemplateId",
+                                          key,
                                           "procTest",
                                           "test.0.1",
                                           "Test Proc",
@@ -205,11 +217,13 @@ public class ProcessInstanceListPresenterTest {
 
         filterSettings.setKey("key");
         filterSettings.setDataSetLookup(dataSetLookup);
+        dataSetLookup.setDataSetUUID(datasetUId);
 
         when(viewMock.getListGrid()).thenReturn(extendedPagedTable);
         when(extendedPagedTable.getPageSize()).thenReturn(10);
         when(filterSettingsJSONMarshaller.fromJsonString(anyString())).thenReturn(filterSettings);
         when(dataSetQueryHelper.getCurrentTableSettings()).thenReturn(filterSettings);
+        when(filterSettings.getUUID()).thenReturn(datasetUId);
         when(filterSettingsManager.getVariablesFilterSettings(any())).thenReturn(filterSettings);
         when(serverTemplateSelectorMenuBuilder.getView()).thenReturn(mock(ServerTemplateSelectorMenuBuilder.ServerTemplateSelectorElementView.class));
         when(perspectiveManager.getCurrentPerspective()).thenReturn(perspectiveActivity);
@@ -237,6 +251,8 @@ public class ProcessInstanceListPresenterTest {
         commonConstants = org.jbpm.workbench.common.client.resources.i18n.Constants.INSTANCE;
 
         presenter.setProcessService(remoteProcessServiceCaller);
+
+        when(errorHandlerBuilder.get()).thenReturn(errorHandler);
     }
 
     @Test
@@ -253,24 +269,35 @@ public class ProcessInstanceListPresenterTest {
                times(2)).hideBusyIndicator();
     }
 
+    @Test
+    public void testRemoveActiveFilter() {
+        final String processId = "testProc";
+        presenter.removeActiveFilter(equalsTo(COLUMN_PROCESS_ID, processId));
+
+        verify(viewMock).removeDomainSpecifColumns();
+
+        reset(viewMock);
+
+        presenter.removeActiveFilter(in(COLUMN_PROCESS_ID, Arrays.asList(processId)));
+
+        verify(viewMock, never()).removeDomainSpecifColumns();
+    }
+
     @Test
     public void isFilteredByProcessIdTest() {
         final String processId = "testProc";
         final DataSetFilter filter = new DataSetFilter();
-        filter.addFilterColumn(equalsTo(COLUMN_PROCESS_ID,
-                                        processId));
+        filter.addFilterColumn(equalsTo(COLUMN_PROCESS_ID, processId));
 
         final String filterProcessId = presenter.isFilteredByProcessId(Collections.<DataSetOp>singletonList(filter));
-        assertEquals(processId,
-                     filterProcessId);
+        assertEquals(processId, filterProcessId);
     }
 
     @Test
     public void isFilteredByProcessIdInvalidTest() {
         final String processId = "testProc";
         final DataSetFilter filter = new DataSetFilter();
-        filter.addFilterColumn(likeTo(COLUMN_PROCESS_ID,
-                                      processId));
+        filter.addFilterColumn(likeTo(COLUMN_PROCESS_ID, processId));
 
         final String filterProcessId = presenter.isFilteredByProcessId(Collections.<DataSetOp>singletonList(filter));
         assertNull(filterProcessId);
@@ -284,9 +311,9 @@ public class ProcessInstanceListPresenterTest {
         presenter.abortProcessInstance(containerId,
                                        processInstanceId);
 
-        verify(processService).abortProcessInstance(anyString(),
-                                                    eq(containerId),
-                                                    eq(processInstanceId));
+        verify(processService).abortProcessInstance(new ProcessInstanceKey("",
+                                                                           containerId,
+                                                                           processInstanceId));
         verify(viewMock).displayNotification(Constants.INSTANCE.Aborting_Process_Instance(processInstanceId));
     }
 
@@ -315,8 +342,8 @@ public class ProcessInstanceListPresenterTest {
 
         presenter.bulkAbort(processInstanceSummaries);
 
-        verify(processService).abortProcessInstances(anyString(),
-                                                     eq(containerInstance));
+        verify(processService).abortProcessInstances(anyString(), eq(containerInstance));
+        verify(extendedPagedTable).deselectAllItems();
     }
 
     @Test
@@ -409,8 +436,7 @@ public class ProcessInstanceListPresenterTest {
                                     5));
 
         ArgumentCaptor<Set> argument = ArgumentCaptor.forClass(Set.class);
-        verify(viewMock).addDomainSpecifColumns(any(ExtendedPagedTable.class),
-                                                argument.capture());
+        verify(viewMock).addDomainSpecifColumns(argument.capture());
 
         assertEquals(expectedColumns,
                      argument.getValue());
@@ -437,9 +463,7 @@ public class ProcessInstanceListPresenterTest {
                                     5));
 
         argument = ArgumentCaptor.forClass(Set.class);
-        verify(viewMock,
-               times(2)).addDomainSpecifColumns(any(ExtendedPagedTable.class),
-                                                argument.capture());
+        verify(viewMock, times(2)).addDomainSpecifColumns(argument.capture());
 
         assertEquals(expectedColumns,
                      argument.getValue());
@@ -539,42 +563,64 @@ public class ProcessInstanceListPresenterTest {
     }
 
     @Test
-    public void testDefaultActiveSearchFilters() {
-        presenter.setupDefaultActiveSearchFilters();
+    public void testExistActiveSearchFilters() {
+        final PlaceRequest place = mock(PlaceRequest.class);
+        presenter.onStartup(place);
 
-        ArgumentCaptor<ActiveFilterItem> captor = ArgumentCaptor.forClass(ActiveFilterItem.class);
-        verify(viewMock).addActiveFilter(captor.capture());
+        when(place.getParameter(SEARCH_PARAMETER_PROCESS_INSTANCE_ID, null)).thenReturn("1");
+        assertTrue(presenter.existActiveSearchFilters());
 
-        assertEquals(1,
-                     captor.getAllValues().size());
-        assertEquals(Constants.INSTANCE.State(),
-                     captor.getValue().getKey());
-        assertEquals(Constants.INSTANCE.State() + ": " + Constants.INSTANCE.Active(),
-                     captor.getValue().getLabelValue());
-        assertEquals(ProcessInstance.STATE_ACTIVE,
-                     (captor.getValue().getValue()));
+        when(place.getParameter(SEARCH_PARAMETER_PROCESS_DEFINITION_ID, null)).thenReturn("1");
+        assertTrue(presenter.existActiveSearchFilters());
+
+        when(place.getParameter(SEARCH_PARAMETER_PROCESS_INSTANCE_ID, null)).thenReturn(null);
+        when(place.getParameter(SEARCH_PARAMETER_PROCESS_DEFINITION_ID, null)).thenReturn(null);
+        assertFalse(presenter.existActiveSearchFilters());
     }
 
     @Test
-    public void testActiveSearchFilters() {
-        final PlaceRequest place = mock(PlaceRequest.class);
-        when(place.getParameter(anyString(),
-                                anyString())).thenReturn(null);
-        presenter.onStartup(place);
+    public void testActiveFilterLabelStatus() {
+        ColumnFilter testColumFilter = equalsTo(COLUMN_STATUS,
+                                                Arrays.asList(String.valueOf(ProcessInstance.STATE_ACTIVE),
+                                                              String.valueOf(ProcessInstance.STATE_COMPLETED)));
 
-        presenter.setupActiveSearchFilters();
+        ActiveFilterItem activeFilterItem = presenter.getActiveFilterFromColumnFilter(testColumFilter);
 
-        ArgumentCaptor<ActiveFilterItem> captor = ArgumentCaptor.forClass(ActiveFilterItem.class);
-        verify(viewMock).addActiveFilter(captor.capture());
+        assertEquals(Constants.INSTANCE.State(), activeFilterItem.getKey());
+        assertEquals(Constants.INSTANCE.State() + ": " + Constants.INSTANCE.Active() + ", " + Constants.INSTANCE.Completed(),
+                     activeFilterItem.getLabelValue());
+        assertNotEquals(testColumFilter.toString(), activeFilterItem.getLabelValue());
+    }
 
-        assertEquals(1,
-                     captor.getAllValues().size());
-        assertEquals(Constants.INSTANCE.State(),
-                     captor.getValue().getKey());
-        assertEquals(Constants.INSTANCE.State() + ": " + Constants.INSTANCE.Active(),
-                     captor.getValue().getLabelValue());
-        assertEquals(ProcessInstance.STATE_ACTIVE,
-                     (captor.getValue().getValue()));
+    @Test
+    public void testActiveFilterLabelOther() {
+        ColumnFilter testColumFilter = equalsTo(COLUMN_PROCESS_ID, "evaluation");
+        ActiveFilterItem activeFilterItem = presenter.getActiveFilterFromColumnFilter(testColumFilter);
+        assertEquals(COLUMN_PROCESS_ID, activeFilterItem.getKey());
+        assertEquals(testColumFilter.toString(), activeFilterItem.getLabelValue());
+
+        testColumFilter = equalsTo(COLUMN_PROCESS_INSTANCE_ID, 1);
+        activeFilterItem = presenter.getActiveFilterFromColumnFilter(testColumFilter);
+        assertEquals(COLUMN_PROCESS_INSTANCE_ID, activeFilterItem.getKey());
+        assertEquals(testColumFilter.toString(), activeFilterItem.getLabelValue());
+    }
+
+    @Test
+    public void testGetActiveFilterFromColumnFilter() {
+        ColumnFilter testStateColumFilter = equalsTo(COLUMN_STATUS, "Active");
+        ActiveFilterItem activeStateFilterItem = presenter.getActiveFilterFromColumnFilter(testStateColumFilter);
+        assertEquals("State", activeStateFilterItem.getKey());
+        assertEquals("Active", ((List<String>) activeStateFilterItem.getValue()).get(0));
+
+        ColumnFilter testWithErrorsColumFilter = greaterThan(COLUMN_ERROR_COUNT, "0");
+        ActiveFilterItem activeWithErrorsFilterItem = presenter.getActiveFilterFromColumnFilter(testWithErrorsColumFilter);
+        assertEquals(COLUMN_ERROR_COUNT, activeWithErrorsFilterItem.getKey());
+        assertEquals("true", ((List<String>) activeWithErrorsFilterItem.getValue()).get(0));
+
+        ColumnFilter testWithoutErrorsColumFilter = lowerOrEqualsTo(COLUMN_ERROR_COUNT, "1");
+        ActiveFilterItem activeWithoutErrorsFilterItem = presenter.getActiveFilterFromColumnFilter(testWithoutErrorsColumFilter);
+        assertEquals(COLUMN_ERROR_COUNT, activeWithoutErrorsFilterItem.getKey());
+        assertEquals("false", ((List<String>) activeWithoutErrorsFilterItem.getValue()).get(0));
     }
 
     @Test
@@ -736,19 +782,6 @@ public class ProcessInstanceListPresenterTest {
                      captor.getAllValues().get(1).getIdentifier());
     }
 
-    @Test
-    public void testCreateDataSetProcessInstanceCallbackOnError() {
-        final ProcessInstanceListPresenter spy = spy(presenter);
-        final ClientRuntimeError error = new ClientRuntimeError("");
-        final FilterSettings filterSettings = mock(FilterSettings.class);
-        final DataSetReadyCallback callback = spy.getDataSetReadyCallback(0,
-                                                                          filterSettings);
-        doNothing().when(spy).showErrorPopup(any());
-        assertFalse(callback.onError(error));
-        verify(viewMock).hideBusyIndicator();
-        verify(spy).showErrorPopup(Constants.INSTANCE.ResourceCouldNotBeLoaded(commonConstants.Process_Instances()));
-    }
-
     @Test
     public void testListBreadcrumbCreation() {
         presenter.createListBreadcrumb();
@@ -823,7 +856,16 @@ public class ProcessInstanceListPresenterTest {
                                                                        null,
                                                                        null);
         final ColumnFilter columnFilter = mock(ColumnFilter.class);
-        presenter.onBasicFilterAddEvent(new BasicFilterAddEvent(filter,
+        presenter.onBasicFilterAddEvent(new BasicFilterAddEvent("ProcessInstanceLogDataset",
+                                                                filter,
+                                                                columnFilter));
+        verify(viewMock,
+               never()).addActiveFilter(filter);
+        verify(filterSettings,
+               never()).addColumnFilter(columnFilter);
+
+        presenter.onBasicFilterAddEvent(new BasicFilterAddEvent(datasetUId,
+                                                                filter,
                                                                 columnFilter));
 
         verify(viewMock).addActiveFilter(filter);
@@ -838,7 +880,16 @@ public class ProcessInstanceListPresenterTest {
                                                                        null,
                                                                        null);
         final ColumnFilter columnFilter = mock(ColumnFilter.class);
-        presenter.onBasicFilterRemoveEvent(new BasicFilterRemoveEvent(filter,
+        presenter.onBasicFilterRemoveEvent(new BasicFilterRemoveEvent("ProcessInstanceLogDataset",
+                                                                      filter,
+                                                                      columnFilter));
+        verify(viewMock,
+               never()).removeActiveFilter(filter);
+        verify(filterSettings,
+               never()).removeColumnFilter(columnFilter);
+
+        presenter.onBasicFilterRemoveEvent(new BasicFilterRemoveEvent(datasetUId,
+                                                                      filter,
                                                                       columnFilter));
 
         verify(viewMock).removeActiveFilter(filter);
@@ -860,7 +911,7 @@ public class ProcessInstanceListPresenterTest {
     }
 
     @Test
-    public void testFilterInitiator(){
+    public void testFilterInitiator() {
         String variableNameWithInitiator = "initiator";
         String variableValueWithInitiator = "initiator people";
 
